__all__ = (
    "Faculty",
    "Direction",
    "Specialization",
    "StudyForm",
    "Application",
    "User",
    "AdditionalInfo",
    "EducationInfo",
    "PassportData"
)

from src.models import Application
from src.models import Faculty
from src.models import Direction
from src.models import Specialization
from src.models import StudyForm

from src.models import User
from  src.models import EducationInfo
from src.models import AdditionalInfo
from src.models import PassportData